/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.component.api;

/**
 * Defines the interface that a component needs to implement.
 * @author Florent Benoit
 */
public interface Component {

    /**
     * Init method.<br/>
     * This method is called before the start method.
     * @throws ComponentException if the initialization has failed.
     */
    void init() throws ComponentException;


    /**
     * Start method.<br/>
     * This method is called after the init method.
     * @throws ComponentException if the start has failed.
     */
    void start() throws ComponentException;


    /**
     * Stop method.<br/>
     * This method is called when component needs to be stopped.
     * @throws ComponentException if the stop is failing.
     */
    void stop() throws ComponentException;

}
