/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.component.api;

/**
 * Interface of the component manager that is managing the components.
 * @author Florent Benoit
 */
public interface IComponentManager {

    /**
     * @return the component registry used by this manager.
     */
    IComponentRegistry getComponentRegistry();

    /**
     * Init the components by calling init() method.
     * @throws ComponentException if initialization fails
     */
    void initComponents() throws ComponentException;

    /**
     * Start the components.
     * @throws ComponentException if starting is failing
     */
    void startComponents() throws ComponentException;

    /**
     * Stop the components.
     */
    void stopComponents();
}

