/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.component.api;

import java.util.List;

/**
 * This interface is the registry of the Components.
 * @author Florent Benoit
 */
public interface IComponentRegistry {

    /**
     * Allow to get a reference on another component.
     * @param componentName the name of the component
     * @return the component.
     */
    Component getComponent(final String componentName);

    /**
     * @param component EZBComponent instance.
     * @return Returns the component name from the EZBComponent instance.
     */
    String getComponentName(final Component component);

    /**
     * Get the components that implements the given interface.
     * @param itf the given interface
     * @return an array of components implementing the given interface
     * @param <T> an interface extending EZBComponent.
     */
    <T extends Component> List<T> getComponents(final Class<T> itf);

    /**
     * Register a component.
     * @param componentName the name of the component to register
     * @param component the component to register.
     * @throws ComponentException if registering fails.
     */
    void register(final String componentName, final Component component) throws ComponentException;

    /**
     * Unregister a component.
     * @param componentName the component name to unregister.
     * @throws ComponentException if unregistering fails.
     */
    void unregister(final String componentName) throws ComponentException;

    /**
     * Unregister a component.
     * @param component the instance of the component to unregister.
     * @throws ComponentException if unregistering fails.
     */
    void unregister(final Component component) throws ComponentException;
}
